
``${script}``
======================================

**Usage**::

    pulsar-main [options]

**Help**


Daemonized entry point for Pulsar services.

**Options**::


      -h, --help            show this help message and exit
      -c CONFIG_DIR, --config_dir=CONFIG_DIR
      --ini_path=INI_PATH   
      --app_conf_path=APP_CONF_PATH
      --app=APP             
      -d, --daemonize       Daemonzie process
      --daemon-log-file=DAEMON_LOG_FILE
                            log file for daemon script
      --pid-file=PID_FILE   pid file (default is pulsar.pid)
    
